==> v1.51.zip: combo/combo/apps/dataviz/forms.py <==
# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.conf import settings

from combo.utils import requests

from .models import ChartCell


class ChartForm(forms.ModelForm):
    class Meta:
        model = ChartCell
        fields = ('title', 'url')

    def __init__(self, *args, **kwargs):
        super(ChartForm, self).__init__(*args, **kwargs)
        available_charts = []
        for site_key, site_dict in settings.KNOWN_SERVICES.get('bijoe').items():
            result = requests.get('/visualization/json/',
                    remote_service=site_dict, without_user=True,
                    headers={'accept': 'application/json'}).json()
            available_charts.extend([(x['path'], x['name']) for x in result])
        available_charts.sort(key=lambda x: x[1])
        self.fields['url'].widget = forms.Select(choices=available_charts)

==> v2.53.zip: combo/combo/apps/dataviz/forms.py <==
# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from combo.utils import requests

from .models import ChartCell, ChartNgCell


class ChartForm(forms.ModelForm):
    class Meta:
        model = ChartCell
        fields = ('title', 'url')

    def __init__(self, *args, **kwargs):
        super(ChartForm, self).__init__(*args, **kwargs)
        available_charts = []
        for site_key, site_dict in settings.KNOWN_SERVICES.get('bijoe').items():
            result = requests.get('/visualization/json/',
                    remote_service=site_dict, without_user=True,
                    headers={'accept': 'application/json'}).json()
            available_charts.extend([(x['path'], x['name']) for x in result])
        available_charts.sort(key=lambda x: x[1])
        self.fields['url'].widget = forms.Select(choices=available_charts)


class ChartNgForm(forms.ModelForm):
    class Meta:
        model = ChartNgCell
        fields = ('title', 'data_reference', 'chart_type', 'height')

    def __init__(self, *args, **kwargs):
        super(ChartNgForm, self).__init__(*args, **kwargs)
        data_references = []
        bijoe_sites = settings.KNOWN_SERVICES.get('bijoe').items()
        for site_key, site_dict in bijoe_sites:
            result = requests.get('/visualization/json/',
                    remote_service=site_dict, without_user=True,
                    headers={'accept': 'application/json'}).json()
            if len(bijoe_sites) > 1:
                label_prefix = _('%s: ') % site_dict.get('title')
            else:
                label_prefix = ''
            data_references.extend([
                ('%s:%s' % (site_key, x['slug']), '%s%s' % (label_prefix, x['name']))
                for x in result])

        data_references.sort(key=lambda x: x[1])
        self.fields['data_reference'].widget = forms.Select(choices=data_references)
